reset
set terminal postscript enhanced color
set output 'frqnoise.ps'

clp(f,f0) = 1/(1+{0,1}*f/f0)
lp(f,f0) = 1/sqrt(1+f**2/f0**2)

nan = sqrt(-1)
req_freq(f) = (f<0.1) ? nan : (f<0.4) ? 1000 : (f<1) ? 100 : (f<10) ? 3 : (f<20) ? 1 : (f<1000) ? 20/f : (f<10000) ? 2e-2 : nan
req_npro(f) = 10e3/f

db(x)=20.*log10(abs(x))
dbm(x) = 10**((x+10*log10(50.)-30)/20.) # dbm to volt
dbv(x) = 10**(x/20.)    # dbV to volt

set samples 1000

set title 'Injection-locking frequency noise'

set logscale xy
set xlabel 'frequency (Hz)'
set format x "%.0s%c"
set ylabel 'frequency noise (Hz Hz^{-1/2})'
set format y "10^{%T}" # "%.0te%T"
set grid x y mx my
set mxtics 10
set mytics 10
set key right top 
set style data lines

ecali=5.72e-8
ccali=2.53e-9

plot [1:100e3] \
	req_npro(x) title 'NPRO' lt 1 lc 4, \
 'SRS107.DAT' u 1:($2/ecali) title 'error signal' lt 1 lc 1 w l,\
 'SRS109.DAT' u 1:($2/ecali) notitle lt 1 lc 1 w l,\
 'SRS111.DAT' u 1:($2/ecali) notitle lt 1 lc 1 w l,\
 'SRS113.DAT' u 1:($2/ecali) notitle lt 1 lc 1 w l,\
 'SRS115.DAT' u 1:($2/ecali) notitle lt 1 lc 1 w l,\
 'SRS117.DAT' u 1:($2/ecali) notitle lt 1 lc 1 w l,\
 '../e/SRS108.DAT' u 1:($2/ccali*lp($1,250)) title 'control signal' lt 1 lc 2 w l,\
 '../e/SRS110.DAT' u 1:($2/ccali*lp($1,250)) notitle lt 1 lc 2 w l,\
 '../e/SRS112.DAT' u 1:($2/ccali*lp($1,250)) notitle lt 1 lc 2 w l,\
 '../e/SRS114.DAT' u 1:($2/ccali*lp($1,250)) notitle lt 1 lc 2 w l,\
 '../e/SRS116.DAT' u 1:($2/ccali*lp($1,250)) notitle lt 1 lc 2 w l,\
 '../e/SRS118.DAT' u 1:($2/ccali*lp($1,250)) notitle lt 1 lc 2 w l

system('epstopdf --autorotate=All  frqnoise.ps')